==> grilo_0.2.11.orig.tar.xz: grilo-0.2.11/tools/grilo-inspect/grl-core-keys.h <==
gchar *grl_core_keys[] = {
"GRL_METADATA_KEY_INVALID",
"GRL_METADATA_KEY_ALBUM",
"GRL_METADATA_KEY_ARTIST",
"GRL_METADATA_KEY_AUTHOR",
"GRL_METADATA_KEY_BITRATE",
"GRL_METADATA_KEY_CERTIFICATE",
"GRL_METADATA_KEY_CHILDCOUNT",
"GRL_METADATA_KEY_PUBLICATION_DATE",
"GRL_METADATA_KEY_DESCRIPTION",
"GRL_METADATA_KEY_DURATION",
"GRL_METADATA_KEY_EXTERNAL_PLAYER",
"GRL_METADATA_KEY_EXTERNAL_URL",
"GRL_METADATA_KEY_FRAMERATE",
"GRL_METADATA_KEY_GENRE",
"GRL_METADATA_KEY_HEIGHT",
"GRL_METADATA_KEY_ID",
"GRL_METADATA_KEY_LAST_PLAYED",
"GRL_METADATA_KEY_LAST_POSITION",
"GRL_METADATA_KEY_LICENSE",
"GRL_METADATA_KEY_LYRICS",
"GRL_METADATA_KEY_MIME",
"GRL_METADATA_KEY_PLAY_COUNT",
"GRL_METADATA_KEY_RATING",
"GRL_METADATA_KEY_SITE",
"GRL_METADATA_KEY_SOURCE",
"GRL_METADATA_KEY_STUDIO",
"GRL_METADATA_KEY_THUMBNAIL",
"GRL_METADATA_KEY_THUMBNAIL_BINARY",
"GRL_METADATA_KEY_TITLE",
"GRL_METADATA_KEY_URL",
"GRL_METADATA_KEY_WIDTH",
"GRL_METADATA_KEY_SEASON",
"GRL_METADATA_KEY_EPISODE",
"GRL_METADATA_KEY_SHOW",
"GRL_METADATA_KEY_CREATION_DATE",
"GRL_METADATA_KEY_CAMERA_MODEL",
"GRL_METADATA_KEY_ORIENTATION",
"GRL_METADATA_KEY_FLASH_USED",
"GRL_METADATA_KEY_EXPOSURE_TIME",
"GRL_METADATA_KEY_ISO_SPEED",
"GRL_METADATA_KEY_TRACK_NUMBER",
"GRL_METADATA_KEY_MODIFICATION_DATE",
"GRL_METADATA_KEY_START_TIME",
"GRL_METADATA_KEY_FAVOURITE",
"GRL_METADATA_KEY_REGION",
"GRL_METADATA_KEY_KEYWORD",
"GRL_METADATA_KEY_PERFORMER",
"GRL_METADATA_KEY_PRODUCER",
"GRL_METADATA_KEY_DIRECTOR",
"GRL_METADATA_KEY_ORIGINAL_TITLE",
"GRL_METADATA_KEY_SIZE",
"GRL_METADATA_KEY_TITLE_FROM_FILENAME",
"GRL_METADATA_KEY_MB_ALBUM_ID",
};

==> grilo_0.2.15.orig.tar.xz: grilo-0.2.15/tools/grilo-inspect/grl-core-keys.h <==
gchar *grl_core_keys[] = {
"GRL_METADATA_KEY_INVALID",
"GRL_METADATA_KEY_ALBUM",
"GRL_METADATA_KEY_ARTIST",
"GRL_METADATA_KEY_AUTHOR",
"GRL_METADATA_KEY_BITRATE",
"GRL_METADATA_KEY_CERTIFICATE",
"GRL_METADATA_KEY_CHILDCOUNT",
"GRL_METADATA_KEY_PUBLICATION_DATE",
"GRL_METADATA_KEY_DESCRIPTION",
"GRL_METADATA_KEY_DURATION",
"GRL_METADATA_KEY_EXTERNAL_PLAYER",
"GRL_METADATA_KEY_EXTERNAL_URL",
"GRL_METADATA_KEY_FRAMERATE",
"GRL_METADATA_KEY_GENRE",
"GRL_METADATA_KEY_HEIGHT",
"GRL_METADATA_KEY_ID",
"GRL_METADATA_KEY_LAST_PLAYED",
"GRL_METADATA_KEY_LAST_POSITION",
"GRL_METADATA_KEY_LICENSE",
"GRL_METADATA_KEY_LYRICS",
"GRL_METADATA_KEY_MIME",
"GRL_METADATA_KEY_PLAY_COUNT",
"GRL_METADATA_KEY_RATING",
"GRL_METADATA_KEY_SITE",
"GRL_METADATA_KEY_SOURCE",
"GRL_METADATA_KEY_STUDIO",
"GRL_METADATA_KEY_THUMBNAIL",
"GRL_METADATA_KEY_THUMBNAIL_BINARY",
"GRL_METADATA_KEY_TITLE",
"GRL_METADATA_KEY_URL",
"GRL_METADATA_KEY_WIDTH",
"GRL_METADATA_KEY_SEASON",
"GRL_METADATA_KEY_EPISODE",
"GRL_METADATA_KEY_SHOW",
"GRL_METADATA_KEY_CREATION_DATE",
"GRL_METADATA_KEY_CAMERA_MODEL",
"GRL_METADATA_KEY_ORIENTATION",
"GRL_METADATA_KEY_FLASH_USED",
"GRL_METADATA_KEY_EXPOSURE_TIME",
"GRL_METADATA_KEY_ISO_SPEED",
"GRL_METADATA_KEY_TRACK_NUMBER",
"GRL_METADATA_KEY_MODIFICATION_DATE",
"GRL_METADATA_KEY_START_TIME",
"GRL_METADATA_KEY_FAVOURITE",
"GRL_METADATA_KEY_REGION",
"GRL_METADATA_KEY_KEYWORD",
"GRL_METADATA_KEY_PERFORMER",
"GRL_METADATA_KEY_PRODUCER",
"GRL_METADATA_KEY_DIRECTOR",
"GRL_METADATA_KEY_ORIGINAL_TITLE",
"GRL_METADATA_KEY_SIZE",
"GRL_METADATA_KEY_TITLE_FROM_FILENAME",
"GRL_METADATA_KEY_MB_ALBUM_ID",
"GRL_METADATA_KEY_MB_TRACK_ID",
"GRL_METADATA_KEY_MB_ARTIST_ID",
"GRL_METADATA_KEY_MB_RECORDING_ID",
"GRL_METADATA_KEY_EPISODE_TITLE",
"GRL_METADATA_KEY_AUDIO_TRACK",
};
